@@ -6,11 +6,11 @@ Log::ProgramInfo - log global info from a perl programs.
 
 =head1 VERSION
 
-Version 0.1.12
+Version 0.1.13
 
 =cut
 
-our $VERSION = '0.1.12';
+our $VERSION = '0.1.13';
 
 use feature qw(say);
 use Data::Dumper;
@@ -379,15 +379,20 @@ my $log;
 
 sub log_entry {
     my $msg;
-    @_ = map { $_ // 'NO_VALUE_FOUND' } @_;
-    if (@_ == 2 ) {
-        $msg = sprintf "%-7s : %s", @_;
-    } elsif (@_ == 3 ) {
-        $msg = sprintf "%-7s : %-8s : %s", @_;
+	my @vals = @_;
+    for (@vals) {
+	    $_ = 'NO_VALUE_FOUND' unless length($_);
+	    s/\t/<TAB>/g;
+        s/\n/<NL>/g;
+    }
+    if (@vals == 2 ) {
+        $msg = sprintf "%-7s : %s", @vals;
+    } elsif (@vals == 3 ) {
+        $msg = sprintf "%-7s : %-8s : %s", @vals;
     } else {
         my $msg = "log_entry needs 2 or 3 arguments, got "
-            . scalar(@_);
-        $msg .= ': (' . join( '), (', @_ ) . ')' if @_;
+            . scalar(@vals);
+        $msg .= ': (' . join( '), (', @vals ) . ')' if @vals;
         cluck $msg;
     }
     _log_entry( $msg );
